#!/bin/bash

# create kafka-jaas conf
cat >${HOME}/kafka_jaas.conf <<EOF
Client {
  org.apache.kafka.common.security.plain.PlainLoginModule required
  username="${KAFKA_JAAS_USERNAME}"
  password="${KAFKA_JAAS_PASSWORD}";
};
EOF

# create adminclient props
cat >${HOME}/adminclient.props <<EOF
security.protocol=SSL
ssl.truststore.type=PKCS12
ssl.keystore.location=${SSL_KEYSTORE_LOCATION}
ssl.truststore.password=${SSL_TRUSTSTORE_PASSWORD}
ssl.keystore.type=PKCS12
ssl.truststore.location=${SSL_TRUSTSTORE_LOCATION}
ssl.keystore.password=${SSL_KEYSTORE_PASSWORD}
ssl.key.password=${SSL_KEY_PASSWORD}
ssl.endpoint.identification.algorithm=
ssl.enabled.protocols=TLSv1.2
EOF

# provide kafka opts
export KAFKA_OPTS="-Dzookeeper.clientCnxnSocket=org.apache.zookeeper.ClientCnxnSocketNetty
-Dzookeeper.client.secure=true
-Dzookeeper.ssl.keyStore.location=$SSL_KEYSTORE_LOCATION
-Dzookeeper.ssl.keyStore.password=$SSL_KEYSTORE_PASSWORD
-Dzookeeper.ssl.trustStore.location=$SSL_TRUSTSTORE_LOCATION
-Dzookeeper.ssl.trustStore.password=$SSL_TRUSTSTORE_PASSWORD
-Dzookeeper.ssl.hostnameVerification=false
-Djava.security.auth.login.config=${HOME}/kafka_jaas.conf"

set -eux

# call kakfa-topics script
/opt/kafka/bin/kafka-topics.sh \
    --zookeeper ${ZOOKEEPER_SERVICE_HOST}:${ZOOKEEPER_SERVICE_PORT_CLIENT_TLS} \
    --command-config ${HOME}/adminclient.props \
    --create \
    --if-not-exists \
    "$@"
